==> dde-calendar_5.8.29.orig.tar.xz: dde-calendar-5.8.29/translations/dde-calendar-service_en_US.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en_US">
<context>
    <name>JobRemindManager</name>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <source>One day before start</source>
        <translation>One day before start</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="109"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Close</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <source>Remind me tomorrow</source>
        <translation>Remind me tomorrow</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <source>Remind me later</source>
        <translation>Remind me later</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="116"/>
        <source>Schedule Reminder</source>
        <translation>Schedule Reminder</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="236"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="245"/>
        <source>%1 to %2</source>
        <translation>%1 to %2</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="317"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="328"/>
        <source>Today</source>
        <translation>Today</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="320"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="331"/>
        <source>Tomorrow</source>
        <translation>Tomorrow</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_en_US.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="en_US">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Work</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Life</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Other</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Close</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>One day before start</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Remind me tomorrow</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Remind me later</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 mins later</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 hour later</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 hours later</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Tomorrow</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Schedule Reminder</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 to %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Today</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">One day before start</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Close</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Remind me tomorrow</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Remind me later</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Schedule Reminder</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 to %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Today</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Tomorrow</translation>
    </message>
</context>
</TS>
